# JSON Engine

please refer to `` for the python package

and please refer to `` for the repo

# Download Package

`py -m pip install csvengine -U`

## In Your Python Files

`import csvengine.main as eng`
